embassy-stm32

Crates

git

Versions

stm32g471re

Flavors

TamperStatus

Struct TamperStatus 

pub struct TamperStatus { /* private fields */ }
Snapshot of which tamper channels/conditions have a latched detection flag.

Implementations

Source

impl TamperStatus

pub fn is_external(&self, channel: u8) -> bool

Whether external channel channel has a latched detection flag.

pub fn is_internal(&self, tamper: u8) -> bool

Whether internal tamper tamper has a latched detection flag.

pub fn any(&self) -> bool

Whether any channel or internal tamper has a latched detection flag.